/**
 * NOTE: THIS IS A GENERATED FILE. PLEASE CONSULT THE ORIGINAL IDL FILE
 * FOR THE FULL DOCUMENTION AND LICENSE.
 *
 * @see <a href="http://lxr.mozilla.org/mozilla/search?string=interface+nsIDOMSVGSymbolElem">
 **/

package org.mozilla.xpcom;

public interface nsIDOMSVGSymbolElement extends nsIDOMSVGElement
{
  public static final String NS_IDOMSVGSYMBOLELEMENT_IID =
    "{86092181-a5db-4a89-be03-07dcc14d426e}";

}
